# coding: utf-8

"""
    Secore API

    API for the Seres core platform

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class FutureActivityType(str, Enum):
    """
    FutureActivityType
    """

    """
    allowed enum values
    """
    FLIGHT_PLAN_CREATED = 'flight_plan_created'
    FLIGHT_PLAN_CANCELLED = 'flight_plan_cancelled'
    FLIGHT_PLAN_LEG_CREATED = 'flight_plan_leg_created'
    FLIGHT_PLAN_LEG_CANCELLED = 'flight_plan_leg_cancelled'
    FLIGHT_PLAN_LEG_RESOURCE_CREATED = 'flight_plan_leg_resource_created'
    FLIGHT_PLAN_LEG_RESOURCE_CANCELLED = 'flight_plan_leg_resource_cancelled'
    FLIGHT_PLAN_WAYPOINT_CREATED = 'flight_plan_waypoint_created'
    FLIGHT_PLAN_WAYPOINT_CANCELLED = 'flight_plan_waypoint_cancelled'
    PAD_OPERATION_CREATED = 'pad_operation_created'
    PAD_OPERATION_CANCELLED = 'pad_operation_cancelled'
    BAY_OPERATION_CREATED = 'bay_operation_created'
    BAY_OPERATION_CANCELLED = 'bay_operation_cancelled'
    BAY_OPERATION_RESOURCE_CREATED = 'bay_operation_resource_created'
    BAY_OPERATION_RESOURCE_CANCELLED = 'bay_operation_resource_cancelled'
    BAY_ALLOCATION_CREATED = 'bay_allocation_created'
    BAY_ALLOCATION_CANCELLED = 'bay_allocation_cancelled'
    RESOURCE_ALLOCATION_CREATED = 'resource_allocation_created'
    RESOURCE_ALLOCATION_CANCELLED = 'resource_allocation_cancelled'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of FutureActivityType from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    Secore API

    API for the Seres core platform

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from seres_client.models.paginated_response_schema_access_key_schema import PaginatedResponseSchemaAccessKeySchema

class TestPaginatedResponseSchemaAccessKeySchema(unittest.TestCase):
    """PaginatedResponseSchemaAccessKeySchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PaginatedResponseSchemaAccessKeySchema:
        """Test PaginatedResponseSchemaAccessKeySchema
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PaginatedResponseSchemaAccessKeySchema`
        """
        model = PaginatedResponseSchemaAccessKeySchema()
        if include_optional:
            return PaginatedResponseSchemaAccessKeySchema(
                items = [
                    seres_client.models.access_key_schema.AccessKeySchema(
                        name = '', 
                        description = '', 
                        permission_ids = [
                            56
                            ], 
                        id = 56, 
                        created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        status = 'active', 
                        expires = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        created_by_id = 56, 
                        account_id = 56, 
                        key = '', 
                        permissions = [
                            seres_client.models.permission_schema.PermissionSchema(
                                id = 56, 
                                string = '', 
                                referenced = True, )
                            ], )
                    ],
                has_next = True,
                has_prev = True,
                next_num = 56,
                prev_num = 56,
                page = 56,
                pages = 56,
                total = 56,
                per_page = 56
            )
        else:
            return PaginatedResponseSchemaAccessKeySchema(
                items = [
                    seres_client.models.access_key_schema.AccessKeySchema(
                        name = '', 
                        description = '', 
                        permission_ids = [
                            56
                            ], 
                        id = 56, 
                        created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        status = 'active', 
                        expires = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        created_by_id = 56, 
                        account_id = 56, 
                        key = '', 
                        permissions = [
                            seres_client.models.permission_schema.PermissionSchema(
                                id = 56, 
                                string = '', 
                                referenced = True, )
                            ], )
                    ],
                has_next = True,
                has_prev = True,
                page = 56,
                pages = 56,
                total = 56,
                per_page = 56,
        )
        """

    def testPaginatedResponseSchemaAccessKeySchema(self):
        """Test PaginatedResponseSchemaAccessKeySchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Secore API

    API for the Seres core platform

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictInt, StrictStr
from typing import Optional
from typing_extensions import Annotated
from seres_client.models.flight_plan_creation_request_creation_schema import FlightPlanCreationRequestCreationSchema
from seres_client.models.flight_plan_creation_request_schema import FlightPlanCreationRequestSchema
from seres_client.models.flight_plan_creation_request_status_enum import FlightPlanCreationRequestStatusEnum
from seres_client.models.paginated_response_schema_flight_plan_creation_request_schema import PaginatedResponseSchemaFlightPlanCreationRequestSchema

from seres_client.api_client import ApiClient, RequestSerialized
from seres_client.api_response import ApiResponse
from seres_client.rest import RESTResponseType


class FlightPlanCreationRequestsApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def create_flight_plan_creation_request(
        self,
        flight_plan_creation_request_creation_schema: FlightPlanCreationRequestCreationSchema,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> FlightPlanCreationRequestSchema:
        """Create Flight Plan Creation Request

        Create a flight plan creation request. This will trigger the crreation of a flight plan

        :param flight_plan_creation_request_creation_schema: (required)
        :type flight_plan_creation_request_creation_schema: FlightPlanCreationRequestCreationSchema
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._create_flight_plan_creation_request_serialize(
            flight_plan_creation_request_creation_schema=flight_plan_creation_request_creation_schema,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '201': "FlightPlanCreationRequestSchema",
            '401': None,
            '400': None,
            '404': None,
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def create_flight_plan_creation_request_with_http_info(
        self,
        flight_plan_creation_request_creation_schema: FlightPlanCreationRequestCreationSchema,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[FlightPlanCreationRequestSchema]:
        """Create Flight Plan Creation Request

        Create a flight plan creation request. This will trigger the crreation of a flight plan

        :param flight_plan_creation_request_creation_schema: (required)
        :type flight_plan_creation_request_creation_schema: FlightPlanCreationRequestCreationSchema
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._create_flight_plan_creation_request_serialize(
            flight_plan_creation_request_creation_schema=flight_plan_creation_request_creation_schema,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '201': "FlightPlanCreationRequestSchema",
            '401': None,
            '400': None,
            '404': None,
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def create_flight_plan_creation_request_without_preload_content(
        self,
        flight_plan_creation_request_creation_schema: FlightPlanCreationRequestCreationSchema,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Create Flight Plan Creation Request

        Create a flight plan creation request. This will trigger the crreation of a flight plan

        :param flight_plan_creation_request_creation_schema: (required)
        :type flight_plan_creation_request_creation_schema: FlightPlanCreationRequestCreationSchema
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._create_flight_plan_creation_request_serialize(
            flight_plan_creation_request_creation_schema=flight_plan_creation_request_creation_schema,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '201': "FlightPlanCreationRequestSchema",
            '401': None,
            '400': None,
            '404': None,
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _create_flight_plan_creation_request_serialize(
        self,
        flight_plan_creation_request_creation_schema,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if flight_plan_creation_request_creation_schema is not None:
            _body_params = flight_plan_creation_request_creation_schema


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'APIKeyHeader', 
            'APIKeyCookie'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/api/flight-plan-creation-requests',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_flight_plan_creation_request(
        self,
        request_id: StrictInt,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> FlightPlanCreationRequestSchema:
        """Get Flight Plan Creation Request

        Get the given flight plan creation request

        :param request_id: (required)
        :type request_id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_flight_plan_creation_request_serialize(
            request_id=request_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "FlightPlanCreationRequestSchema",
            '401': None,
            '404': None,
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_flight_plan_creation_request_with_http_info(
        self,
        request_id: StrictInt,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[FlightPlanCreationRequestSchema]:
        """Get Flight Plan Creation Request

        Get the given flight plan creation request

        :param request_id: (required)
        :type request_id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_flight_plan_creation_request_serialize(
            request_id=request_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "FlightPlanCreationRequestSchema",
            '401': None,
            '404': None,
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_flight_plan_creation_request_without_preload_content(
        self,
        request_id: StrictInt,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get Flight Plan Creation Request

        Get the given flight plan creation request

        :param request_id: (required)
        :type request_id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_flight_plan_creation_request_serialize(
            request_id=request_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "FlightPlanCreationRequestSchema",
            '401': None,
            '404': None,
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_flight_plan_creation_request_serialize(
        self,
        request_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if request_id is not None:
            _path_params['request_id'] = request_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'APIKeyHeader', 
            'APIKeyCookie'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/flight-plan-creation-requests/{request_id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_flight_plan_creation_requests(
        self,
        account_id: Optional[StrictInt] = None,
        status: Optional[FlightPlanCreationRequestStatusEnum] = None,
        order_by: Annotated[Optional[StrictStr], Field(description="Comma delimited list of fields to order by, with options: created, -created")] = None,
        page: Optional[StrictInt] = None,
        per_page: Optional[StrictInt] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> PaginatedResponseSchemaFlightPlanCreationRequestSchema:
        """Get Flight Plan Creation Requests

        Get flight plan creation requests

        :param account_id:
        :type account_id: int
        :param status:
        :type status: FlightPlanCreationRequestStatusEnum
        :param order_by: Comma delimited list of fields to order by, with options: created, -created
        :type order_by: str
        :param page:
        :type page: int
        :param per_page:
        :type per_page: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_flight_plan_creation_requests_serialize(
            account_id=account_id,
            status=status,
            order_by=order_by,
            page=page,
            per_page=per_page,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "PaginatedResponseSchemaFlightPlanCreationRequestSchema",
            '401': None,
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_flight_plan_creation_requests_with_http_info(
        self,
        account_id: Optional[StrictInt] = None,
        status: Optional[FlightPlanCreationRequestStatusEnum] = None,
        order_by: Annotated[Optional[StrictStr], Field(description="Comma delimited list of fields to order by, with options: created, -created")] = None,
        page: Optional[StrictInt] = None,
        per_page: Optional[StrictInt] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[PaginatedResponseSchemaFlightPlanCreationRequestSchema]:
        """Get Flight Plan Creation Requests

        Get flight plan creation requests

        :param account_id:
        :type account_id: int
        :param status:
        :type status: FlightPlanCreationRequestStatusEnum
        :param order_by: Comma delimited list of fields to order by, with options: created, -created
        :type order_by: str
        :param page:
        :type page: int
        :param per_page:
        :type per_page: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_flight_plan_creation_requests_serialize(
            account_id=account_id,
            status=status,
            order_by=order_by,
            page=page,
            per_page=per_page,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "PaginatedResponseSchemaFlightPlanCreationRequestSchema",
            '401': None,
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_flight_plan_creation_requests_without_preload_content(
        self,
        account_id: Optional[StrictInt] = None,
        status: Optional[FlightPlanCreationRequestStatusEnum] = None,
        order_by: Annotated[Optional[StrictStr], Field(description="Comma delimited list of fields to order by, with options: created, -created")] = None,
        page: Optional[StrictInt] = None,
        per_page: Optional[StrictInt] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get Flight Plan Creation Requests

        Get flight plan creation requests

        :param account_id:
        :type account_id: int
        :param status:
        :type status: FlightPlanCreationRequestStatusEnum
        :param order_by: Comma delimited list of fields to order by, with options: created, -created
        :type order_by: str
        :param page:
        :type page: int
        :param per_page:
        :type per_page: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_flight_plan_creation_requests_serialize(
            account_id=account_id,
            status=status,
            order_by=order_by,
            page=page,
            per_page=per_page,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "PaginatedResponseSchemaFlightPlanCreationRequestSchema",
            '401': None,
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_flight_plan_creation_requests_serialize(
        self,
        account_id,
        status,
        order_by,
        page,
        per_page,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if account_id is not None:
            
            _query_params.append(('account_id', account_id))
            
        if status is not None:
            
            _query_params.append(('status', status.value))
            
        if order_by is not None:
            
            _query_params.append(('order_by', order_by))
            
        if page is not None:
            
            _query_params.append(('page', page))
            
        if per_page is not None:
            
            _query_params.append(('per_page', per_page))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'APIKeyHeader', 
            'APIKeyCookie'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/flight-plan-creation-requests',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    Secore API

    API for the Seres core platform

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from seres_client.models.port_coordinate import PortCoordinate

class TestPortCoordinate(unittest.TestCase):
    """PortCoordinate unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PortCoordinate:
        """Test PortCoordinate
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PortCoordinate`
        """
        model = PortCoordinate()
        if include_optional:
            return PortCoordinate(
                longitude = '',
                latitude = '',
                elevation = '0'
            )
        else:
            return PortCoordinate(
                longitude = '',
                latitude = '',
        )
        """

    def testPortCoordinate(self):
        """Test PortCoordinate"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Secore API

    API for the Seres core platform

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from seres_client.models.flight_plan_type_enum import FlightPlanTypeEnum

class TestFlightPlanTypeEnum(unittest.TestCase):
    """FlightPlanTypeEnum unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testFlightPlanTypeEnum(self):
        """Test FlightPlanTypeEnum"""
        # inst = FlightPlanTypeEnum()

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Secore API

    API for the Seres core platform

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from seres_client.api.access_keys_api import AccessKeysApi


class TestAccessKeysApi(unittest.TestCase):
    """AccessKeysApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AccessKeysApi()

    def tearDown(self) -> None:
        pass

    def test_create_access_key(self) -> None:
        """Test case for create_access_key

        Create Access Key
        """
        pass

    def test_disable_access_key(self) -> None:
        """Test case for disable_access_key

        Disable Access Key
        """
        pass

    def test_get_access_key(self) -> None:
        """Test case for get_access_key

        Get Access Key
        """
        pass

    def test_get_access_key_me(self) -> None:
        """Test case for get_access_key_me

        Get Access Key Me
        """
        pass

    def test_get_access_keys(self) -> None:
        """Test case for get_access_keys

        Get Access Keys
        """
        pass

    def test_reactivate_access_key(self) -> None:
        """Test case for reactivate_access_key

        Reactivate Access Key
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Secore API

    API for the Seres core platform

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from seres_client.models.resource_schema_schema import ResourceSchemaSchema

class TestResourceSchemaSchema(unittest.TestCase):
    """ResourceSchemaSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ResourceSchemaSchema:
        """Test ResourceSchemaSchema
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ResourceSchemaSchema`
        """
        model = ResourceSchemaSchema()
        if include_optional:
            return ResourceSchemaSchema(
                model = '',
                resource_type = 'payload',
                id = 56,
                created = '',
                status = 'new',
                decommission_datetime = None,
                actions = [
                    seres_client.models.resource_schema_action_schema.ResourceSchemaActionSchema(
                        resource_schema_id = 56, 
                        resource_schema_action_schema_id = 56, 
                        consumption_rate = 56, 
                        duration = 56, 
                        id = 56, 
                        name = '', )
                    ],
                has_preview = True,
                energy_profile = seres_client.models.resource_schema_energy_profile_schema.ResourceSchemaEnergyProfileSchema(
                    resource_schema_id = 56, 
                    milliamp_hour_capacity = 56, 
                    charge_max_cycles = 56, 
                    id = 56, )
            )
        else:
            return ResourceSchemaSchema(
                model = '',
                resource_type = 'payload',
                id = 56,
                created = '',
                status = 'new',
                actions = [
                    seres_client.models.resource_schema_action_schema.ResourceSchemaActionSchema(
                        resource_schema_id = 56, 
                        resource_schema_action_schema_id = 56, 
                        consumption_rate = 56, 
                        duration = 56, 
                        id = 56, 
                        name = '', )
                    ],
                has_preview = True,
        )
        """

    def testResourceSchemaSchema(self):
        """Test ResourceSchemaSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Secore API

    API for the Seres core platform

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from seres_client.api.subnets_api import SubnetsApi


class TestSubnetsApi(unittest.TestCase):
    """SubnetsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = SubnetsApi()

    def tearDown(self) -> None:
        pass

    def test_get_subnet(self) -> None:
        """Test case for get_subnet

        Get Subnet
        """
        pass

    def test_get_subnets(self) -> None:
        """Test case for get_subnets

        Get Subnets
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Secore API

    API for the Seres core platform

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from seres_client.models.flight_plan_schema_creation_schema import FlightPlanSchemaCreationSchema

class TestFlightPlanSchemaCreationSchema(unittest.TestCase):
    """FlightPlanSchemaCreationSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> FlightPlanSchemaCreationSchema:
        """Test FlightPlanSchemaCreationSchema
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `FlightPlanSchemaCreationSchema`
        """
        model = FlightPlanSchemaCreationSchema()
        if include_optional:
            return FlightPlanSchemaCreationSchema(
                type = 'partial',
                flight_plan_type = 'refuel',
                reference = '',
                waypoints = [
                    seres_client.models.flight_plan_schema_waypoint_immediate_creation_schema.FlightPlanSchemaWaypointImmediateCreationSchema(
                        reference = '', 
                        port_id = 56, 
                        coordinate = seres_client.models.waypoint_coordinate_schema.WaypointCoordinateSchema(
                            longitude = null, 
                            latitude = null, 
                            altitude = null, 
                            elevation = null, ), 
                        temporary_id = 56, 
                        generated = True, )
                    ],
                legs = [
                    seres_client.models.flight_plan_schema_leg_immediate_creation_schema.FlightPlanSchemaLegImmediateCreationSchema(
                        meta_order = 56, 
                        critical = True, 
                        average_speed = null, 
                        duration_seconds = 56, 
                        resource_schema_action_schema_ids = [
                            56
                            ], 
                        origin_waypoint_temporary_id = 56, 
                        generated = True, )
                    ]
            )
        else:
            return FlightPlanSchemaCreationSchema(
                type = 'partial',
                reference = '',
        )
        """

    def testFlightPlanSchemaCreationSchema(self):
        """Test FlightPlanSchemaCreationSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Secore API

    API for the Seres core platform

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from seres_client.api.resource_schema_actions_api import ResourceSchemaActionsApi


class TestResourceSchemaActionsApi(unittest.TestCase):
    """ResourceSchemaActionsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ResourceSchemaActionsApi()

    def tearDown(self) -> None:
        pass

    def test_get_resource_schema_action(self) -> None:
        """Test case for get_resource_schema_action

        Get Resource Schema Action
        """
        pass

    def test_get_resource_schema_actions(self) -> None:
        """Test case for get_resource_schema_actions

        Get Resource Schema Actions
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Secore API

    API for the Seres core platform

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from seres_client.models.paginated_response_schema_resource_assembly_schema_schema import PaginatedResponseSchemaResourceAssemblySchemaSchema

class TestPaginatedResponseSchemaResourceAssemblySchemaSchema(unittest.TestCase):
    """PaginatedResponseSchemaResourceAssemblySchemaSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PaginatedResponseSchemaResourceAssemblySchemaSchema:
        """Test PaginatedResponseSchemaResourceAssemblySchemaSchema
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PaginatedResponseSchemaResourceAssemblySchemaSchema`
        """
        model = PaginatedResponseSchemaResourceAssemblySchemaSchema()
        if include_optional:
            return PaginatedResponseSchemaResourceAssemblySchemaSchema(
                items = [
                    seres_client.models.resource_assembly_schema_schema.ResourceAssemblySchemaSchema(
                        reference = '', 
                        is_partial = True, 
                        id = 56, 
                        status = 'new', 
                        components = [
                            seres_client.models.resource_assembly_schema_component_schema.ResourceAssemblySchemaComponentSchema(
                                resource_assembly_schema_id = 56, 
                                parent_resource_assembly_schema_component_id = 56, 
                                resource_schema_id = 56, 
                                configuration = 'primary', 
                                position_reference = '', 
                                is_main = True, 
                                id = 56, 
                                meta_energy_bank_consumer_link_needs_defining = True, 
                                meta_energy_bank_component_link_could_need_defining = True, 
                                resource_schema_type = 'payload', )
                            ], 
                        meta_default_configuration_ready = True, 
                        meta_movement_profiles_ready = True, 
                        meta_energy_configuration_ready = True, )
                    ],
                has_next = True,
                has_prev = True,
                next_num = 56,
                prev_num = 56,
                page = 56,
                pages = 56,
                total = 56,
                per_page = 56
            )
        else:
            return PaginatedResponseSchemaResourceAssemblySchemaSchema(
                items = [
                    seres_client.models.resource_assembly_schema_schema.ResourceAssemblySchemaSchema(
                        reference = '', 
                        is_partial = True, 
                        id = 56, 
                        status = 'new', 
                        components = [
                            seres_client.models.resource_assembly_schema_component_schema.ResourceAssemblySchemaComponentSchema(
                                resource_assembly_schema_id = 56, 
                                parent_resource_assembly_schema_component_id = 56, 
                                resource_schema_id = 56, 
                                configuration = 'primary', 
                                position_reference = '', 
                                is_main = True, 
                                id = 56, 
                                meta_energy_bank_consumer_link_needs_defining = True, 
                                meta_energy_bank_component_link_could_need_defining = True, 
                                resource_schema_type = 'payload', )
                            ], 
                        meta_default_configuration_ready = True, 
                        meta_movement_profiles_ready = True, 
                        meta_energy_configuration_ready = True, )
                    ],
                has_next = True,
                has_prev = True,
                page = 56,
                pages = 56,
                total = 56,
                per_page = 56,
        )
        """

    def testPaginatedResponseSchemaResourceAssemblySchemaSchema(self):
        """Test PaginatedResponseSchemaResourceAssemblySchemaSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# flake8: noqa

# import apis into api package
from seres_client.api.access_keys_api import AccessKeysApi
from seres_client.api.authentication_api import AuthenticationApi
from seres_client.api.available_resource_assemblies_api import AvailableResourceAssembliesApi
from seres_client.api.flight_plan_creation_requests_api import FlightPlanCreationRequestsApi
from seres_client.api.flight_plan_leg_resources_api import FlightPlanLegResourcesApi
from seres_client.api.flight_plan_legs_api import FlightPlanLegsApi
from seres_client.api.flight_plan_references_api import FlightPlanReferencesApi
from seres_client.api.flight_plan_schema_legs_api import FlightPlanSchemaLegsApi
from seres_client.api.flight_plan_schema_waypoints_api import FlightPlanSchemaWaypointsApi
from seres_client.api.flight_plan_schemas_api import FlightPlanSchemasApi
from seres_client.api.flight_plan_waypoints_api import FlightPlanWaypointsApi
from seres_client.api.flight_plans_api import FlightPlansApi
from seres_client.api.future_activities_api import FutureActivitiesApi
from seres_client.api.futures_api import FuturesApi
from seres_client.api.pad_windows_api import PadWindowsApi
from seres_client.api.ports_api import PortsApi
from seres_client.api.resource_assembly_schema_energy_bank_components_api import ResourceAssemblySchemaEnergyBankComponentsApi
from seres_client.api.resource_assembly_schema_energy_bank_consumers_api import ResourceAssemblySchemaEnergyBankConsumersApi
from seres_client.api.resource_assembly_schema_energy_banks_api import ResourceAssemblySchemaEnergyBanksApi
from seres_client.api.resource_assembly_schema_refuel_swaps_api import ResourceAssemblySchemaRefuelSwapsApi
from seres_client.api.resource_assembly_schemas_api import ResourceAssemblySchemasApi
from seres_client.api.resource_schema_action_schemas_api import ResourceSchemaActionSchemasApi
from seres_client.api.resource_schema_actions_api import ResourceSchemaActionsApi
from seres_client.api.resource_schemas_api import ResourceSchemasApi
from seres_client.api.resources_api import ResourcesApi
from seres_client.api.subnets_api import SubnetsApi
from seres_client.api.users_api import UsersApi




# coding: utf-8

"""
    Secore API

    API for the Seres core platform

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from seres_client.models.available_resource_assembly_schema_component_schema import AvailableResourceAssemblySchemaComponentSchema

class TestAvailableResourceAssemblySchemaComponentSchema(unittest.TestCase):
    """AvailableResourceAssemblySchemaComponentSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AvailableResourceAssemblySchemaComponentSchema:
        """Test AvailableResourceAssemblySchemaComponentSchema
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AvailableResourceAssemblySchemaComponentSchema`
        """
        model = AvailableResourceAssemblySchemaComponentSchema()
        if include_optional:
            return AvailableResourceAssemblySchemaComponentSchema(
                type = 'payload',
                resource_assembly_schema_component_id = 56,
                resource_id = 56,
                resource_schema_id = 56,
                is_primary = True,
                configuration = 'primary',
                resource_schema_actions = [
                    seres_client.models.available_resource_assembly_schema_component_resource_schema_action_schema.AvailableResourceAssemblySchemaComponentResourceSchemaActionSchema(
                        resource_schema_action_id = 56, 
                        resource_schema_action_schema_id = 56, )
                    ]
            )
        else:
            return AvailableResourceAssemblySchemaComponentSchema(
                type = 'payload',
                resource_assembly_schema_component_id = 56,
                resource_id = 56,
                resource_schema_id = 56,
                is_primary = True,
                configuration = 'primary',
                resource_schema_actions = [
                    seres_client.models.available_resource_assembly_schema_component_resource_schema_action_schema.AvailableResourceAssemblySchemaComponentResourceSchemaActionSchema(
                        resource_schema_action_id = 56, 
                        resource_schema_action_schema_id = 56, )
                    ],
        )
        """

    def testAvailableResourceAssemblySchemaComponentSchema(self):
        """Test AvailableResourceAssemblySchemaComponentSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Secore API

    API for the Seres core platform

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from seres_client.models.longitude import Longitude

class TestLongitude(unittest.TestCase):
    """Longitude unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Longitude:
        """Test Longitude
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Longitude`
        """
        model = Longitude()
        if include_optional:
            return Longitude(
            )
        else:
            return Longitude(
        )
        """

    def testLongitude(self):
        """Test Longitude"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Secore API

    API for the Seres core platform

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictBool, StrictInt
from typing import Any, ClassVar, Dict, List, Optional
from seres_client.models.flight_plan_creation_request_schema import FlightPlanCreationRequestSchema
from typing import Optional, Set
from typing_extensions import Self

class PaginatedResponseSchemaFlightPlanCreationRequestSchema(BaseModel):
    """
    PaginatedResponseSchemaFlightPlanCreationRequestSchema
    """ # noqa: E501
    items: List[FlightPlanCreationRequestSchema]
    has_next: StrictBool
    has_prev: StrictBool
    next_num: Optional[StrictInt] = None
    prev_num: Optional[StrictInt] = None
    page: StrictInt
    pages: StrictInt
    total: StrictInt
    per_page: StrictInt
    __properties: ClassVar[List[str]] = ["items", "has_next", "has_prev", "next_num", "prev_num", "page", "pages", "total", "per_page"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PaginatedResponseSchemaFlightPlanCreationRequestSchema from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in items (list)
        _items = []
        if self.items:
            for _item_items in self.items:
                if _item_items:
                    _items.append(_item_items.to_dict())
            _dict['items'] = _items
        # set to None if next_num (nullable) is None
        # and model_fields_set contains the field
        if self.next_num is None and "next_num" in self.model_fields_set:
            _dict['next_num'] = None

        # set to None if prev_num (nullable) is None
        # and model_fields_set contains the field
        if self.prev_num is None and "prev_num" in self.model_fields_set:
            _dict['prev_num'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PaginatedResponseSchemaFlightPlanCreationRequestSchema from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "items": [FlightPlanCreationRequestSchema.from_dict(_item) for _item in obj["items"]] if obj.get("items") is not None else None,
            "has_next": obj.get("has_next"),
            "has_prev": obj.get("has_prev"),
            "next_num": obj.get("next_num"),
            "prev_num": obj.get("prev_num"),
            "page": obj.get("page"),
            "pages": obj.get("pages"),
            "total": obj.get("total"),
            "per_page": obj.get("per_page")
        })
        return _obj





# coding: utf-8

"""
    Secore API

    API for the Seres core platform

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from seres_client.models.paginated_response_schema_resource_schema_schema import PaginatedResponseSchemaResourceSchemaSchema

class TestPaginatedResponseSchemaResourceSchemaSchema(unittest.TestCase):
    """PaginatedResponseSchemaResourceSchemaSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PaginatedResponseSchemaResourceSchemaSchema:
        """Test PaginatedResponseSchemaResourceSchemaSchema
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PaginatedResponseSchemaResourceSchemaSchema`
        """
        model = PaginatedResponseSchemaResourceSchemaSchema()
        if include_optional:
            return PaginatedResponseSchemaResourceSchemaSchema(
                items = [
                    seres_client.models.resource_schema_schema.ResourceSchemaSchema(
                        model = '', 
                        resource_type = 'payload', 
                        id = 56, 
                        created = '', 
                        status = 'new', 
                        decommission_datetime = null, 
                        actions = [
                            seres_client.models.resource_schema_action_schema.ResourceSchemaActionSchema(
                                resource_schema_id = 56, 
                                resource_schema_action_schema_id = 56, 
                                consumption_rate = 56, 
                                duration = 56, 
                                id = 56, 
                                name = '', )
                            ], 
                        has_preview = True, 
                        energy_profile = seres_client.models.resource_schema_energy_profile_schema.ResourceSchemaEnergyProfileSchema(
                            resource_schema_id = 56, 
                            milliamp_hour_capacity = 56, 
                            charge_max_cycles = 56, 
                            id = 56, ), )
                    ],
                has_next = True,
                has_prev = True,
                next_num = 56,
                prev_num = 56,
                page = 56,
                pages = 56,
                total = 56,
                per_page = 56
            )
        else:
            return PaginatedResponseSchemaResourceSchemaSchema(
                items = [
                    seres_client.models.resource_schema_schema.ResourceSchemaSchema(
                        model = '', 
                        resource_type = 'payload', 
                        id = 56, 
                        created = '', 
                        status = 'new', 
                        decommission_datetime = null, 
                        actions = [
                            seres_client.models.resource_schema_action_schema.ResourceSchemaActionSchema(
                                resource_schema_id = 56, 
                                resource_schema_action_schema_id = 56, 
                                consumption_rate = 56, 
                                duration = 56, 
                                id = 56, 
                                name = '', )
                            ], 
                        has_preview = True, 
                        energy_profile = seres_client.models.resource_schema_energy_profile_schema.ResourceSchemaEnergyProfileSchema(
                            resource_schema_id = 56, 
                            milliamp_hour_capacity = 56, 
                            charge_max_cycles = 56, 
                            id = 56, ), )
                    ],
                has_next = True,
                has_prev = True,
                page = 56,
                pages = 56,
                total = 56,
                per_page = 56,
        )
        """

    def testPaginatedResponseSchemaResourceSchemaSchema(self):
        """Test PaginatedResponseSchemaResourceSchemaSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Secore API

    API for the Seres core platform

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictBool, StrictInt, StrictStr
from typing import List, Optional
from typing_extensions import Annotated
from seres_client.models.implementation_status_enum import ImplementationStatusEnum
from seres_client.models.paginated_response_schema_resource_assembly_schema_schema import PaginatedResponseSchemaResourceAssemblySchemaSchema
from seres_client.models.resource_assembly_schema_schema import ResourceAssemblySchemaSchema

from seres_client.api_client import ApiClient, RequestSerialized
from seres_client.api_response import ApiResponse
from seres_client.rest import RESTResponseType


class ResourceAssemblySchemasApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def get_resource_assembly_schema(
        self,
        resource_assembly_schema_id: StrictInt,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ResourceAssemblySchemaSchema:
        """Get Resource Assembly Schema

        Get the given resource assembly schema

        :param resource_assembly_schema_id: (required)
        :type resource_assembly_schema_id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_resource_assembly_schema_serialize(
            resource_assembly_schema_id=resource_assembly_schema_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ResourceAssemblySchemaSchema",
            '401': None,
            '404': None,
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_resource_assembly_schema_with_http_info(
        self,
        resource_assembly_schema_id: StrictInt,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ResourceAssemblySchemaSchema]:
        """Get Resource Assembly Schema

        Get the given resource assembly schema

        :param resource_assembly_schema_id: (required)
        :type resource_assembly_schema_id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_resource_assembly_schema_serialize(
            resource_assembly_schema_id=resource_assembly_schema_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ResourceAssemblySchemaSchema",
            '401': None,
            '404': None,
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_resource_assembly_schema_without_preload_content(
        self,
        resource_assembly_schema_id: StrictInt,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get Resource Assembly Schema

        Get the given resource assembly schema

        :param resource_assembly_schema_id: (required)
        :type resource_assembly_schema_id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_resource_assembly_schema_serialize(
            resource_assembly_schema_id=resource_assembly_schema_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ResourceAssemblySchemaSchema",
            '401': None,
            '404': None,
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_resource_assembly_schema_serialize(
        self,
        resource_assembly_schema_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if resource_assembly_schema_id is not None:
            _path_params['resource_assembly_schema_id'] = resource_assembly_schema_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'APIKeyHeader', 
            'APIKeyCookie'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/resource-assembly-schemas/{resource_assembly_schema_id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_resource_assembly_schemas(
        self,
        main_component_resource_schema_ids: Annotated[Optional[List[Optional[StrictInt]]], Field(description="Filter assemblies that have these resource schemas as main components")] = None,
        primary_resource_schema_ids: Annotated[Optional[List[StrictInt]], Field(description="Filter assemblies that have these resource schemas as primary components")] = None,
        secondary_resource_schema_ids: Annotated[Optional[List[StrictInt]], Field(description="Filter assemblies that have these resource schemas as secondary components")] = None,
        resource_schema_id: Annotated[Optional[StrictInt], Field(description="Filter assemblies that use this resource schema in any capacity")] = None,
        useable: Annotated[Optional[StrictBool], Field(description="Filter assemblies that can be used by a port (launch, landing, storage are supported, and the assembly is active)")] = None,
        useable_by_port_ids: Annotated[Optional[List[StrictInt]], Field(description="Filter assemblies that can be used by all of the specified ports (launch, landing, storage are supported, and the assembly is active)")] = None,
        is_partial: Optional[StrictBool] = None,
        status: Optional[ImplementationStatusEnum] = None,
        port_id: Annotated[Optional[StrictInt], Field(description="Filter assemblies compatible with this port")] = None,
        has_battery_component: Annotated[Optional[StrictBool], Field(description="Filter resource assembly schemas that have at least one component of battery type. Note that this is based on type, not energy profiles")] = None,
        search: Annotated[Optional[StrictStr], Field(description="Space seperated list of search terms")] = None,
        page: Optional[StrictInt] = None,
        per_page: Optional[StrictInt] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> PaginatedResponseSchemaResourceAssemblySchemaSchema:
        """Get Resource Assembly Schemas

        List the resource assembly schemas

        :param main_component_resource_schema_ids: Filter assemblies that have these resource schemas as main components
        :type main_component_resource_schema_ids: List[Optional[int]]
        :param primary_resource_schema_ids: Filter assemblies that have these resource schemas as primary components
        :type primary_resource_schema_ids: List[int]
        :param secondary_resource_schema_ids: Filter assemblies that have these resource schemas as secondary components
        :type secondary_resource_schema_ids: List[int]
        :param resource_schema_id: Filter assemblies that use this resource schema in any capacity
        :type resource_schema_id: int
        :param useable: Filter assemblies that can be used by a port (launch, landing, storage are supported, and the assembly is active)
        :type useable: bool
        :param useable_by_port_ids: Filter assemblies that can be used by all of the specified ports (launch, landing, storage are supported, and the assembly is active)
        :type useable_by_port_ids: List[int]
        :param is_partial:
        :type is_partial: bool
        :param status:
        :type status: ImplementationStatusEnum
        :param port_id: Filter assemblies compatible with this port
        :type port_id: int
        :param has_battery_component: Filter resource assembly schemas that have at least one component of battery type. Note that this is based on type, not energy profiles
        :type has_battery_component: bool
        :param search: Space seperated list of search terms
        :type search: str
        :param page:
        :type page: int
        :param per_page:
        :type per_page: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_resource_assembly_schemas_serialize(
            main_component_resource_schema_ids=main_component_resource_schema_ids,
            primary_resource_schema_ids=primary_resource_schema_ids,
            secondary_resource_schema_ids=secondary_resource_schema_ids,
            resource_schema_id=resource_schema_id,
            useable=useable,
            useable_by_port_ids=useable_by_port_ids,
            is_partial=is_partial,
            status=status,
            port_id=port_id,
            has_battery_component=has_battery_component,
            search=search,
            page=page,
            per_page=per_page,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "PaginatedResponseSchemaResourceAssemblySchemaSchema",
            '401': None,
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_resource_assembly_schemas_with_http_info(
        self,
        main_component_resource_schema_ids: Annotated[Optional[List[Optional[StrictInt]]], Field(description="Filter assemblies that have these resource schemas as main components")] = None,
        primary_resource_schema_ids: Annotated[Optional[List[StrictInt]], Field(description="Filter assemblies that have these resource schemas as primary components")] = None,
        secondary_resource_schema_ids: Annotated[Optional[List[StrictInt]], Field(description="Filter assemblies that have these resource schemas as secondary components")] = None,
        resource_schema_id: Annotated[Optional[StrictInt], Field(description="Filter assemblies that use this resource schema in any capacity")] = None,
        useable: Annotated[Optional[StrictBool], Field(description="Filter assemblies that can be used by a port (launch, landing, storage are supported, and the assembly is active)")] = None,
        useable_by_port_ids: Annotated[Optional[List[StrictInt]], Field(description="Filter assemblies that can be used by all of the specified ports (launch, landing, storage are supported, and the assembly is active)")] = None,
        is_partial: Optional[StrictBool] = None,
        status: Optional[ImplementationStatusEnum] = None,
        port_id: Annotated[Optional[StrictInt], Field(description="Filter assemblies compatible with this port")] = None,
        has_battery_component: Annotated[Optional[StrictBool], Field(description="Filter resource assembly schemas that have at least one component of battery type. Note that this is based on type, not energy profiles")] = None,
        search: Annotated[Optional[StrictStr], Field(description="Space seperated list of search terms")] = None,
        page: Optional[StrictInt] = None,
        per_page: Optional[StrictInt] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[PaginatedResponseSchemaResourceAssemblySchemaSchema]:
        """Get Resource Assembly Schemas

        List the resource assembly schemas

        :param main_component_resource_schema_ids: Filter assemblies that have these resource schemas as main components
        :type main_component_resource_schema_ids: List[Optional[int]]
        :param primary_resource_schema_ids: Filter assemblies that have these resource schemas as primary components
        :type primary_resource_schema_ids: List[int]
        :param secondary_resource_schema_ids: Filter assemblies that have these resource schemas as secondary components
        :type secondary_resource_schema_ids: List[int]
        :param resource_schema_id: Filter assemblies that use this resource schema in any capacity
        :type resource_schema_id: int
        :param useable: Filter assemblies that can be used by a port (launch, landing, storage are supported, and the assembly is active)
        :type useable: bool
        :param useable_by_port_ids: Filter assemblies that can be used by all of the specified ports (launch, landing, storage are supported, and the assembly is active)
        :type useable_by_port_ids: List[int]
        :param is_partial:
        :type is_partial: bool
        :param status:
        :type status: ImplementationStatusEnum
        :param port_id: Filter assemblies compatible with this port
        :type port_id: int
        :param has_battery_component: Filter resource assembly schemas that have at least one component of battery type. Note that this is based on type, not energy profiles
        :type has_battery_component: bool
        :param search: Space seperated list of search terms
        :type search: str
        :param page:
        :type page: int
        :param per_page:
        :type per_page: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_resource_assembly_schemas_serialize(
            main_component_resource_schema_ids=main_component_resource_schema_ids,
            primary_resource_schema_ids=primary_resource_schema_ids,
            secondary_resource_schema_ids=secondary_resource_schema_ids,
            resource_schema_id=resource_schema_id,
            useable=useable,
            useable_by_port_ids=useable_by_port_ids,
            is_partial=is_partial,
            status=status,
            port_id=port_id,
            has_battery_component=has_battery_component,
            search=search,
            page=page,
            per_page=per_page,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "PaginatedResponseSchemaResourceAssemblySchemaSchema",
            '401': None,
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_resource_assembly_schemas_without_preload_content(
        self,
        main_component_resource_schema_ids: Annotated[Optional[List[Optional[StrictInt]]], Field(description="Filter assemblies that have these resource schemas as main components")] = None,
        primary_resource_schema_ids: Annotated[Optional[List[StrictInt]], Field(description="Filter assemblies that have these resource schemas as primary components")] = None,
        secondary_resource_schema_ids: Annotated[Optional[List[StrictInt]], Field(description="Filter assemblies that have these resource schemas as secondary components")] = None,
        resource_schema_id: Annotated[Optional[StrictInt], Field(description="Filter assemblies that use this resource schema in any capacity")] = None,
        useable: Annotated[Optional[StrictBool], Field(description="Filter assemblies that can be used by a port (launch, landing, storage are supported, and the assembly is active)")] = None,
        useable_by_port_ids: Annotated[Optional[List[StrictInt]], Field(description="Filter assemblies that can be used by all of the specified ports (launch, landing, storage are supported, and the assembly is active)")] = None,
        is_partial: Optional[StrictBool] = None,
        status: Optional[ImplementationStatusEnum] = None,
        port_id: Annotated[Optional[StrictInt], Field(description="Filter assemblies compatible with this port")] = None,
        has_battery_component: Annotated[Optional[StrictBool], Field(description="Filter resource assembly schemas that have at least one component of battery type. Note that this is based on type, not energy profiles")] = None,
        search: Annotated[Optional[StrictStr], Field(description="Space seperated list of search terms")] = None,
        page: Optional[StrictInt] = None,
        per_page: Optional[StrictInt] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get Resource Assembly Schemas

        List the resource assembly schemas

        :param main_component_resource_schema_ids: Filter assemblies that have these resource schemas as main components
        :type main_component_resource_schema_ids: List[Optional[int]]
        :param primary_resource_schema_ids: Filter assemblies that have these resource schemas as primary components
        :type primary_resource_schema_ids: List[int]
        :param secondary_resource_schema_ids: Filter assemblies that have these resource schemas as secondary components
        :type secondary_resource_schema_ids: List[int]
        :param resource_schema_id: Filter assemblies that use this resource schema in any capacity
        :type resource_schema_id: int
        :param useable: Filter assemblies that can be used by a port (launch, landing, storage are supported, and the assembly is active)
        :type useable: bool
        :param useable_by_port_ids: Filter assemblies that can be used by all of the specified ports (launch, landing, storage are supported, and the assembly is active)
        :type useable_by_port_ids: List[int]
        :param is_partial:
        :type is_partial: bool
        :param status:
        :type status: ImplementationStatusEnum
        :param port_id: Filter assemblies compatible with this port
        :type port_id: int
        :param has_battery_component: Filter resource assembly schemas that have at least one component of battery type. Note that this is based on type, not energy profiles
        :type has_battery_component: bool
        :param search: Space seperated list of search terms
        :type search: str
        :param page:
        :type page: int
        :param per_page:
        :type per_page: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_resource_assembly_schemas_serialize(
            main_component_resource_schema_ids=main_component_resource_schema_ids,
            primary_resource_schema_ids=primary_resource_schema_ids,
            secondary_resource_schema_ids=secondary_resource_schema_ids,
            resource_schema_id=resource_schema_id,
            useable=useable,
            useable_by_port_ids=useable_by_port_ids,
            is_partial=is_partial,
            status=status,
            port_id=port_id,
            has_battery_component=has_battery_component,
            search=search,
            page=page,
            per_page=per_page,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "PaginatedResponseSchemaResourceAssemblySchemaSchema",
            '401': None,
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_resource_assembly_schemas_serialize(
        self,
        main_component_resource_schema_ids,
        primary_resource_schema_ids,
        secondary_resource_schema_ids,
        resource_schema_id,
        useable,
        useable_by_port_ids,
        is_partial,
        status,
        port_id,
        has_battery_component,
        search,
        page,
        per_page,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
            'main_component_resource_schema_ids': 'multi',
            'primary_resource_schema_ids': 'multi',
            'secondary_resource_schema_ids': 'multi',
            'useable_by_port_ids': 'multi',
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if main_component_resource_schema_ids is not None:
            
            _query_params.append(('main_component_resource_schema_ids', main_component_resource_schema_ids))
            
        if primary_resource_schema_ids is not None:
            
            _query_params.append(('primary_resource_schema_ids', primary_resource_schema_ids))
            
        if secondary_resource_schema_ids is not None:
            
            _query_params.append(('secondary_resource_schema_ids', secondary_resource_schema_ids))
            
        if resource_schema_id is not None:
            
            _query_params.append(('resource_schema_id', resource_schema_id))
            
        if useable is not None:
            
            _query_params.append(('useable', useable))
            
        if useable_by_port_ids is not None:
            
            _query_params.append(('useable_by_port_ids', useable_by_port_ids))
            
        if is_partial is not None:
            
            _query_params.append(('is_partial', is_partial))
            
        if status is not None:
            
            _query_params.append(('status', status.value))
            
        if port_id is not None:
            
            _query_params.append(('port_id', port_id))
            
        if has_battery_component is not None:
            
            _query_params.append(('has_battery_component', has_battery_component))
            
        if search is not None:
            
            _query_params.append(('search', search))
            
        if page is not None:
            
            _query_params.append(('page', page))
            
        if per_page is not None:
            
            _query_params.append(('per_page', per_page))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'APIKeyHeader', 
            'APIKeyCookie'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/resource-assembly-schemas',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    Secore API

    API for the Seres core platform

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from seres_client.api.flight_plans_api import FlightPlansApi


class TestFlightPlansApi(unittest.TestCase):
    """FlightPlansApi unit test stubs"""

    def setUp(self) -> None:
        self.api = FlightPlansApi()

    def tearDown(self) -> None:
        pass

    def test_create_flight_plan(self) -> None:
        """Test case for create_flight_plan

        Create Flight Plan
        """
        pass

    def test_delete_flight_plan(self) -> None:
        """Test case for delete_flight_plan

        Delete Flight Plan
        """
        pass

    def test_get_flight_plan(self) -> None:
        """Test case for get_flight_plan

        Get Flight Plan
        """
        pass

    def test_get_flight_plans(self) -> None:
        """Test case for get_flight_plans

        Get Flight Plans
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Secore API

    API for the Seres core platform

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from seres_client.api.futures_api import FuturesApi


class TestFuturesApi(unittest.TestCase):
    """FuturesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = FuturesApi()

    def tearDown(self) -> None:
        pass

    def test_commit_future(self) -> None:
        """Test case for commit_future

        Commit Future
        """
        pass

    def test_create_future(self) -> None:
        """Test case for create_future

        Create Future
        """
        pass

    def test_delete_future(self) -> None:
        """Test case for delete_future

        Delete Future
        """
        pass

    def test_get_future(self) -> None:
        """Test case for get_future

        Get Future
        """
        pass

    def test_get_futures(self) -> None:
        """Test case for get_futures

        Get Futures
        """
        pass

    def test_verify_future(self) -> None:
        """Test case for verify_future

        Verify Future
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Secore API

    API for the Seres core platform

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class FlightPlanSchemaLegSchema(BaseModel):
    """
    FlightPlanSchemaLegSchema
    """ # noqa: E501
    meta_order: StrictInt
    critical: Optional[StrictBool] = Field(default=False, description="Critical legs are uninterruptable and must be performed exactly at the specified time")
    average_speed: Optional[StrictStr] = None
    duration_seconds: Optional[StrictInt] = None
    resource_schema_action_schema_ids: Optional[List[StrictInt]] = None
    origin_waypoint_id: StrictInt
    flight_plan_schema_id: StrictInt
    id: StrictInt
    destination_waypoint_id: Optional[StrictInt] = None
    meta_previous_leg_id: Optional[StrictInt] = None
    meta_next_leg_id: Optional[StrictInt] = None
    is_launch: Optional[StrictBool] = None
    is_landing: Optional[StrictBool] = None
    __properties: ClassVar[List[str]] = ["meta_order", "critical", "average_speed", "duration_seconds", "resource_schema_action_schema_ids", "origin_waypoint_id", "flight_plan_schema_id", "id", "destination_waypoint_id", "meta_previous_leg_id", "meta_next_leg_id", "is_launch", "is_landing"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of FlightPlanSchemaLegSchema from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if average_speed (nullable) is None
        # and model_fields_set contains the field
        if self.average_speed is None and "average_speed" in self.model_fields_set:
            _dict['average_speed'] = None

        # set to None if duration_seconds (nullable) is None
        # and model_fields_set contains the field
        if self.duration_seconds is None and "duration_seconds" in self.model_fields_set:
            _dict['duration_seconds'] = None

        # set to None if destination_waypoint_id (nullable) is None
        # and model_fields_set contains the field
        if self.destination_waypoint_id is None and "destination_waypoint_id" in self.model_fields_set:
            _dict['destination_waypoint_id'] = None

        # set to None if meta_previous_leg_id (nullable) is None
        # and model_fields_set contains the field
        if self.meta_previous_leg_id is None and "meta_previous_leg_id" in self.model_fields_set:
            _dict['meta_previous_leg_id'] = None

        # set to None if meta_next_leg_id (nullable) is None
        # and model_fields_set contains the field
        if self.meta_next_leg_id is None and "meta_next_leg_id" in self.model_fields_set:
            _dict['meta_next_leg_id'] = None

        # set to None if is_launch (nullable) is None
        # and model_fields_set contains the field
        if self.is_launch is None and "is_launch" in self.model_fields_set:
            _dict['is_launch'] = None

        # set to None if is_landing (nullable) is None
        # and model_fields_set contains the field
        if self.is_landing is None and "is_landing" in self.model_fields_set:
            _dict['is_landing'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of FlightPlanSchemaLegSchema from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "meta_order": obj.get("meta_order"),
            "critical": obj.get("critical") if obj.get("critical") is not None else False,
            "average_speed": obj.get("average_speed"),
            "duration_seconds": obj.get("duration_seconds"),
            "resource_schema_action_schema_ids": obj.get("resource_schema_action_schema_ids"),
            "origin_waypoint_id": obj.get("origin_waypoint_id"),
            "flight_plan_schema_id": obj.get("flight_plan_schema_id"),
            "id": obj.get("id"),
            "destination_waypoint_id": obj.get("destination_waypoint_id"),
            "meta_previous_leg_id": obj.get("meta_previous_leg_id"),
            "meta_next_leg_id": obj.get("meta_next_leg_id"),
            "is_launch": obj.get("is_launch"),
            "is_landing": obj.get("is_landing")
        })
        return _obj





# coding: utf-8

"""
    Secore API

    API for the Seres core platform

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from seres_client.models.flight_plan_leg_schema import FlightPlanLegSchema

class TestFlightPlanLegSchema(unittest.TestCase):
    """FlightPlanLegSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> FlightPlanLegSchema:
        """Test FlightPlanLegSchema
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `FlightPlanLegSchema`
        """
        model = FlightPlanLegSchema()
        if include_optional:
            return FlightPlanLegSchema(
                resource_assembly_schema_id = 56,
                critical = True,
                starting_datetime = '',
                is_launch_leg = True,
                is_landing_leg = True,
                origin_waypoint_id = 56,
                flight_plan_id = 56,
                generated = True,
                id = 56,
                future_id = 56,
                created = '',
                cancelled = True,
                created_by_id = 56,
                leg_resources = [
                    seres_client.models.flight_plan_leg_resource_schema.FlightPlanLegResourceSchema(
                        resource_id = 56, 
                        resource_assembly_schema_component_id = 56, 
                        configuration = 'primary', 
                        resource_schema_action_ids = [
                            56
                            ], 
                        leg_id = 56, 
                        id = 56, 
                        future_id = 56, 
                        created = '', 
                        cancelled = True, 
                        created_by_id = 56, )
                    ]
            )
        else:
            return FlightPlanLegSchema(
                resource_assembly_schema_id = 56,
                starting_datetime = '',
                origin_waypoint_id = 56,
                flight_plan_id = 56,
                id = 56,
                future_id = 56,
                created = '',
                cancelled = True,
                created_by_id = 56,
                leg_resources = [
                    seres_client.models.flight_plan_leg_resource_schema.FlightPlanLegResourceSchema(
                        resource_id = 56, 
                        resource_assembly_schema_component_id = 56, 
                        configuration = 'primary', 
                        resource_schema_action_ids = [
                            56
                            ], 
                        leg_id = 56, 
                        id = 56, 
                        future_id = 56, 
                        created = '', 
                        cancelled = True, 
                        created_by_id = 56, )
                    ],
        )
        """

    def testFlightPlanLegSchema(self):
        """Test FlightPlanLegSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Secore API

    API for the Seres core platform

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from seres_client.models.implementation_status_enum import ImplementationStatusEnum
from seres_client.models.resource_schema_action_schema import ResourceSchemaActionSchema
from seres_client.models.resource_schema_energy_profile_schema import ResourceSchemaEnergyProfileSchema
from seres_client.models.resource_type_enum import ResourceTypeEnum
from typing import Optional, Set
from typing_extensions import Self

class ResourceSchemaSchema(BaseModel):
    """
    ResourceSchemaSchema
    """ # noqa: E501
    model: Annotated[str, Field(strict=True, max_length=80)]
    resource_type: ResourceTypeEnum
    id: StrictInt
    created: StrictStr
    status: ImplementationStatusEnum
    decommission_datetime: Optional[Any] = None
    actions: List[ResourceSchemaActionSchema]
    has_preview: StrictBool
    energy_profile: Optional[ResourceSchemaEnergyProfileSchema] = None
    __properties: ClassVar[List[str]] = ["model", "resource_type", "id", "created", "status", "decommission_datetime", "actions", "has_preview", "energy_profile"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ResourceSchemaSchema from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in actions (list)
        _items = []
        if self.actions:
            for _item_actions in self.actions:
                if _item_actions:
                    _items.append(_item_actions.to_dict())
            _dict['actions'] = _items
        # override the default output from pydantic by calling `to_dict()` of energy_profile
        if self.energy_profile:
            _dict['energy_profile'] = self.energy_profile.to_dict()
        # set to None if decommission_datetime (nullable) is None
        # and model_fields_set contains the field
        if self.decommission_datetime is None and "decommission_datetime" in self.model_fields_set:
            _dict['decommission_datetime'] = None

        # set to None if energy_profile (nullable) is None
        # and model_fields_set contains the field
        if self.energy_profile is None and "energy_profile" in self.model_fields_set:
            _dict['energy_profile'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ResourceSchemaSchema from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "model": obj.get("model"),
            "resource_type": obj.get("resource_type"),
            "id": obj.get("id"),
            "created": obj.get("created"),
            "status": obj.get("status"),
            "decommission_datetime": obj.get("decommission_datetime"),
            "actions": [ResourceSchemaActionSchema.from_dict(_item) for _item in obj["actions"]] if obj.get("actions") is not None else None,
            "has_preview": obj.get("has_preview"),
            "energy_profile": ResourceSchemaEnergyProfileSchema.from_dict(obj["energy_profile"]) if obj.get("energy_profile") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Secore API

    API for the Seres core platform

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from seres_client.models.resource_assembly_schema_energy_bank_schema import ResourceAssemblySchemaEnergyBankSchema

class TestResourceAssemblySchemaEnergyBankSchema(unittest.TestCase):
    """ResourceAssemblySchemaEnergyBankSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ResourceAssemblySchemaEnergyBankSchema:
        """Test ResourceAssemblySchemaEnergyBankSchema
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ResourceAssemblySchemaEnergyBankSchema`
        """
        model = ResourceAssemblySchemaEnergyBankSchema()
        if include_optional:
            return ResourceAssemblySchemaEnergyBankSchema(
                resource_assembly_schema_id = 56,
                reference = '',
                id = 56,
                meta_requires_defining = True,
                meta_components_require_defining = True,
                meta_consumers_require_defining = True
            )
        else:
            return ResourceAssemblySchemaEnergyBankSchema(
                resource_assembly_schema_id = 56,
                reference = '',
                id = 56,
                meta_requires_defining = True,
                meta_components_require_defining = True,
                meta_consumers_require_defining = True,
        )
        """

    def testResourceAssemblySchemaEnergyBankSchema(self):
        """Test ResourceAssemblySchemaEnergyBankSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Secore API

    API for the Seres core platform

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from seres_client.models.flight_plan_reference_schema import FlightPlanReferenceSchema

class TestFlightPlanReferenceSchema(unittest.TestCase):
    """FlightPlanReferenceSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> FlightPlanReferenceSchema:
        """Test FlightPlanReferenceSchema
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `FlightPlanReferenceSchema`
        """
        model = FlightPlanReferenceSchema()
        if include_optional:
            return FlightPlanReferenceSchema(
                id = 56,
                expected_status = 'draft',
                type = 'refuel',
                future_id = 56,
                flight_plan_schema_id = 56,
                parent_flight_plan_id = 56,
                account_id = 56,
                reference = '',
                created_by_id = 56,
                starting_datetime = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                ending_datetime = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f')
            )
        else:
            return FlightPlanReferenceSchema(
                id = 56,
                expected_status = 'draft',
                type = 'refuel',
                future_id = 56,
                flight_plan_schema_id = 56,
                parent_flight_plan_id = 56,
                account_id = 56,
                reference = '',
                created_by_id = 56,
                starting_datetime = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                ending_datetime = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
        )
        """

    def testFlightPlanReferenceSchema(self):
        """Test FlightPlanReferenceSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Secore API

    API for the Seres core platform

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from seres_client.models.paginated_response_schema_flight_plan_reference_schema import PaginatedResponseSchemaFlightPlanReferenceSchema

class TestPaginatedResponseSchemaFlightPlanReferenceSchema(unittest.TestCase):
    """PaginatedResponseSchemaFlightPlanReferenceSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PaginatedResponseSchemaFlightPlanReferenceSchema:
        """Test PaginatedResponseSchemaFlightPlanReferenceSchema
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PaginatedResponseSchemaFlightPlanReferenceSchema`
        """
        model = PaginatedResponseSchemaFlightPlanReferenceSchema()
        if include_optional:
            return PaginatedResponseSchemaFlightPlanReferenceSchema(
                items = [
                    seres_client.models.flight_plan_reference_schema.FlightPlanReferenceSchema(
                        id = 56, 
                        expected_status = 'draft', 
                        type = 'refuel', 
                        future_id = 56, 
                        flight_plan_schema_id = 56, 
                        parent_flight_plan_id = 56, 
                        account_id = 56, 
                        reference = '', 
                        created_by_id = 56, 
                        starting_datetime = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        ending_datetime = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ],
                has_next = True,
                has_prev = True,
                next_num = 56,
                prev_num = 56,
                page = 56,
                pages = 56,
                total = 56,
                per_page = 56
            )
        else:
            return PaginatedResponseSchemaFlightPlanReferenceSchema(
                items = [
                    seres_client.models.flight_plan_reference_schema.FlightPlanReferenceSchema(
                        id = 56, 
                        expected_status = 'draft', 
                        type = 'refuel', 
                        future_id = 56, 
                        flight_plan_schema_id = 56, 
                        parent_flight_plan_id = 56, 
                        account_id = 56, 
                        reference = '', 
                        created_by_id = 56, 
                        starting_datetime = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        ending_datetime = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ],
                has_next = True,
                has_prev = True,
                page = 56,
                pages = 56,
                total = 56,
                per_page = 56,
        )
        """

    def testPaginatedResponseSchemaFlightPlanReferenceSchema(self):
        """Test PaginatedResponseSchemaFlightPlanReferenceSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Secore API

    API for the Seres core platform

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from seres_client.models.port_schema import PortSchema

class TestPortSchema(unittest.TestCase):
    """PortSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PortSchema:
        """Test PortSchema
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PortSchema`
        """
        model = PortSchema()
        if include_optional:
            return PortSchema(
                name = '',
                coordinate = seres_client.models.port_coordinate.PortCoordinate(
                    longitude = '', 
                    latitude = '', 
                    elevation = '0', ),
                id = 56,
                created = ''
            )
        else:
            return PortSchema(
                name = '',
                coordinate = seres_client.models.port_coordinate.PortCoordinate(
                    longitude = '', 
                    latitude = '', 
                    elevation = '0', ),
                id = 56,
                created = '',
        )
        """

    def testPortSchema(self):
        """Test PortSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Secore API

    API for the Seres core platform

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict
from typing import Any, ClassVar, Dict, List, Optional
from seres_client.models.altitude import Altitude
from seres_client.models.elevation import Elevation
from seres_client.models.latitude import Latitude
from seres_client.models.longitude import Longitude
from typing import Optional, Set
from typing_extensions import Self

class AppMissionsSchemasSchemasFlightPlanSchemaWaypointSchemaWaypointCoordinateSchemaInput(BaseModel):
    """
    AppMissionsSchemasSchemasFlightPlanSchemaWaypointSchemaWaypointCoordinateSchemaInput
    """ # noqa: E501
    longitude: Longitude
    latitude: Latitude
    altitude: Altitude
    elevation: Optional[Elevation] = None
    __properties: ClassVar[List[str]] = ["longitude", "latitude", "altitude", "elevation"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of AppMissionsSchemasSchemasFlightPlanSchemaWaypointSchemaWaypointCoordinateSchemaInput from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of longitude
        if self.longitude:
            _dict['longitude'] = self.longitude.to_dict()
        # override the default output from pydantic by calling `to_dict()` of latitude
        if self.latitude:
            _dict['latitude'] = self.latitude.to_dict()
        # override the default output from pydantic by calling `to_dict()` of altitude
        if self.altitude:
            _dict['altitude'] = self.altitude.to_dict()
        # override the default output from pydantic by calling `to_dict()` of elevation
        if self.elevation:
            _dict['elevation'] = self.elevation.to_dict()
        # set to None if elevation (nullable) is None
        # and model_fields_set contains the field
        if self.elevation is None and "elevation" in self.model_fields_set:
            _dict['elevation'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of AppMissionsSchemasSchemasFlightPlanSchemaWaypointSchemaWaypointCoordinateSchemaInput from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "longitude": Longitude.from_dict(obj["longitude"]) if obj.get("longitude") is not None else None,
            "latitude": Latitude.from_dict(obj["latitude"]) if obj.get("latitude") is not None else None,
            "altitude": Altitude.from_dict(obj["altitude"]) if obj.get("altitude") is not None else None,
            "elevation": Elevation.from_dict(obj["elevation"]) if obj.get("elevation") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Secore API

    API for the Seres core platform

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class FutureEntityType(str, Enum):
    """
    FutureEntityType
    """

    """
    allowed enum values
    """
    FLIGHT_PLAN = 'flight_plan'
    FLIGHT_PLAN_LEG = 'flight_plan_leg'
    FLIGHT_PLAN_LEG_RESOURCE = 'flight_plan_leg_resource'
    FLIGHT_PLAN_WAYPOINT = 'flight_plan_waypoint'
    PAD_OPERATION = 'pad_operation'
    BAY_OPERATION = 'bay_operation'
    BAY_OPERATION_RESOURCE = 'bay_operation_resource'
    BAY_ALLOCATION = 'bay_allocation'
    RESOURCE_ALLOCATION = 'resource_allocation'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of FutureEntityType from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    Secore API

    API for the Seres core platform

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from seres_client.api.flight_plan_schemas_api import FlightPlanSchemasApi


class TestFlightPlanSchemasApi(unittest.TestCase):
    """FlightPlanSchemasApi unit test stubs"""

    def setUp(self) -> None:
        self.api = FlightPlanSchemasApi()

    def tearDown(self) -> None:
        pass

    def test_activate_flight_plan_schema(self) -> None:
        """Test case for activate_flight_plan_schema

        Activate Flight Plan Schema
        """
        pass

    def test_create_flight_plan_schema(self) -> None:
        """Test case for create_flight_plan_schema

        Create Flight Plan Schema
        """
        pass

    def test_create_flight_plan_schema_revision(self) -> None:
        """Test case for create_flight_plan_schema_revision

        Create Flight Plan Schema Revision
        """
        pass

    def test_create_flight_plan_schema_variation(self) -> None:
        """Test case for create_flight_plan_schema_variation

        Create Flight Plan Schema Variation
        """
        pass

    def test_decommission_flight_plan_schema(self) -> None:
        """Test case for decommission_flight_plan_schema

        Decommission Flight Plan Schema
        """
        pass

    def test_delete_flight_plan_schema(self) -> None:
        """Test case for delete_flight_plan_schema

        Delete Flight Plan Schema
        """
        pass

    def test_get_flight_plan_schema(self) -> None:
        """Test case for get_flight_plan_schema

        Get Flight Plan Schema
        """
        pass

    def test_get_flight_plan_schemas(self) -> None:
        """Test case for get_flight_plan_schemas

        Get Flight Plan Schemas
        """
        pass

    def test_update_flight_plan_schema(self) -> None:
        """Test case for update_flight_plan_schema

        Update Flight Plan Schema
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Secore API

    API for the Seres core platform

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from seres_client.models.flight_plan_schema_schema import FlightPlanSchemaSchema

class TestFlightPlanSchemaSchema(unittest.TestCase):
    """FlightPlanSchemaSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> FlightPlanSchemaSchema:
        """Test FlightPlanSchemaSchema
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `FlightPlanSchemaSchema`
        """
        model = FlightPlanSchemaSchema()
        if include_optional:
            return FlightPlanSchemaSchema(
                type = 'partial',
                flight_plan_type = 'refuel',
                reference = '',
                waypoints = [
                    seres_client.models.flight_plan_schema_waypoint_schema.FlightPlanSchemaWaypointSchema(
                        reference = '', 
                        port_id = 56, 
                        coordinate = seres_client.models.waypoint_coordinate_schema.WaypointCoordinateSchema(
                            longitude = '', 
                            latitude = '', 
                            altitude = '', 
                            elevation = '', ), 
                        flight_plan_schema_id = 56, 
                        id = 56, 
                        port_name = '', )
                    ],
                legs = [
                    seres_client.models.flight_plan_schema_leg_schema.FlightPlanSchemaLegSchema(
                        meta_order = 56, 
                        critical = True, 
                        average_speed = '', 
                        duration_seconds = 56, 
                        resource_schema_action_schema_ids = [
                            56
                            ], 
                        origin_waypoint_id = 56, 
                        flight_plan_schema_id = 56, 
                        id = 56, 
                        destination_waypoint_id = 56, 
                        meta_previous_leg_id = 56, 
                        meta_next_leg_id = 56, 
                        is_launch = True, 
                        is_landing = True, )
                    ],
                revision_of_id = 56,
                variation_of_id = 56,
                id = 56,
                account_id = 56,
                status = 'new'
            )
        else:
            return FlightPlanSchemaSchema(
                type = 'partial',
                reference = '',
                waypoints = [
                    seres_client.models.flight_plan_schema_waypoint_schema.FlightPlanSchemaWaypointSchema(
                        reference = '', 
                        port_id = 56, 
                        coordinate = seres_client.models.waypoint_coordinate_schema.WaypointCoordinateSchema(
                            longitude = '', 
                            latitude = '', 
                            altitude = '', 
                            elevation = '', ), 
                        flight_plan_schema_id = 56, 
                        id = 56, 
                        port_name = '', )
                    ],
                legs = [
                    seres_client.models.flight_plan_schema_leg_schema.FlightPlanSchemaLegSchema(
                        meta_order = 56, 
                        critical = True, 
                        average_speed = '', 
                        duration_seconds = 56, 
                        resource_schema_action_schema_ids = [
                            56
                            ], 
                        origin_waypoint_id = 56, 
                        flight_plan_schema_id = 56, 
                        id = 56, 
                        destination_waypoint_id = 56, 
                        meta_previous_leg_id = 56, 
                        meta_next_leg_id = 56, 
                        is_launch = True, 
                        is_landing = True, )
                    ],
                id = 56,
                account_id = 56,
                status = 'new',
        )
        """

    def testFlightPlanSchemaSchema(self):
        """Test FlightPlanSchemaSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Secore API

    API for the Seres core platform

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from seres_client.models.configuration_enum import ConfigurationEnum
from seres_client.models.resource_type_enum import ResourceTypeEnum
from typing import Optional, Set
from typing_extensions import Self

class ResourceAssemblySchemaComponentSchema(BaseModel):
    """
    ResourceAssemblySchemaComponentSchema
    """ # noqa: E501
    resource_assembly_schema_id: StrictInt
    parent_resource_assembly_schema_component_id: Optional[StrictInt] = None
    resource_schema_id: StrictInt
    configuration: ConfigurationEnum
    position_reference: Optional[StrictStr] = None
    is_main: StrictBool
    id: StrictInt
    meta_energy_bank_consumer_link_needs_defining: StrictBool
    meta_energy_bank_component_link_could_need_defining: StrictBool
    resource_schema_type: ResourceTypeEnum
    __properties: ClassVar[List[str]] = ["resource_assembly_schema_id", "parent_resource_assembly_schema_component_id", "resource_schema_id", "configuration", "position_reference", "is_main", "id", "meta_energy_bank_consumer_link_needs_defining", "meta_energy_bank_component_link_could_need_defining", "resource_schema_type"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ResourceAssemblySchemaComponentSchema from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if parent_resource_assembly_schema_component_id (nullable) is None
        # and model_fields_set contains the field
        if self.parent_resource_assembly_schema_component_id is None and "parent_resource_assembly_schema_component_id" in self.model_fields_set:
            _dict['parent_resource_assembly_schema_component_id'] = None

        # set to None if position_reference (nullable) is None
        # and model_fields_set contains the field
        if self.position_reference is None and "position_reference" in self.model_fields_set:
            _dict['position_reference'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ResourceAssemblySchemaComponentSchema from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "resource_assembly_schema_id": obj.get("resource_assembly_schema_id"),
            "parent_resource_assembly_schema_component_id": obj.get("parent_resource_assembly_schema_component_id"),
            "resource_schema_id": obj.get("resource_schema_id"),
            "configuration": obj.get("configuration"),
            "position_reference": obj.get("position_reference"),
            "is_main": obj.get("is_main"),
            "id": obj.get("id"),
            "meta_energy_bank_consumer_link_needs_defining": obj.get("meta_energy_bank_consumer_link_needs_defining"),
            "meta_energy_bank_component_link_could_need_defining": obj.get("meta_energy_bank_component_link_could_need_defining"),
            "resource_schema_type": obj.get("resource_schema_type")
        })
        return _obj





# coding: utf-8

"""
    Secore API

    API for the Seres core platform

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from seres_client.models.flight_plan_schema_leg_schema import FlightPlanSchemaLegSchema
from seres_client.models.flight_plan_schema_type import FlightPlanSchemaType
from seres_client.models.flight_plan_schema_waypoint_schema import FlightPlanSchemaWaypointSchema
from seres_client.models.flight_plan_type_enum import FlightPlanTypeEnum
from seres_client.models.implementation_status_enum import ImplementationStatusEnum
from typing import Optional, Set
from typing_extensions import Self

class FlightPlanSchemaSchema(BaseModel):
    """
    FlightPlanSchemaSchema
    """ # noqa: E501
    type: FlightPlanSchemaType
    flight_plan_type: Optional[FlightPlanTypeEnum] = None
    reference: Annotated[str, Field(strict=True, max_length=120)]
    waypoints: List[FlightPlanSchemaWaypointSchema]
    legs: List[FlightPlanSchemaLegSchema]
    revision_of_id: Optional[StrictInt] = None
    variation_of_id: Optional[StrictInt] = None
    id: StrictInt
    account_id: StrictInt
    status: ImplementationStatusEnum
    __properties: ClassVar[List[str]] = ["type", "flight_plan_type", "reference", "waypoints", "legs", "revision_of_id", "variation_of_id", "id", "account_id", "status"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of FlightPlanSchemaSchema from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in waypoints (list)
        _items = []
        if self.waypoints:
            for _item_waypoints in self.waypoints:
                if _item_waypoints:
                    _items.append(_item_waypoints.to_dict())
            _dict['waypoints'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in legs (list)
        _items = []
        if self.legs:
            for _item_legs in self.legs:
                if _item_legs:
                    _items.append(_item_legs.to_dict())
            _dict['legs'] = _items
        # set to None if revision_of_id (nullable) is None
        # and model_fields_set contains the field
        if self.revision_of_id is None and "revision_of_id" in self.model_fields_set:
            _dict['revision_of_id'] = None

        # set to None if variation_of_id (nullable) is None
        # and model_fields_set contains the field
        if self.variation_of_id is None and "variation_of_id" in self.model_fields_set:
            _dict['variation_of_id'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of FlightPlanSchemaSchema from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "type": obj.get("type"),
            "flight_plan_type": obj.get("flight_plan_type"),
            "reference": obj.get("reference"),
            "waypoints": [FlightPlanSchemaWaypointSchema.from_dict(_item) for _item in obj["waypoints"]] if obj.get("waypoints") is not None else None,
            "legs": [FlightPlanSchemaLegSchema.from_dict(_item) for _item in obj["legs"]] if obj.get("legs") is not None else None,
            "revision_of_id": obj.get("revision_of_id"),
            "variation_of_id": obj.get("variation_of_id"),
            "id": obj.get("id"),
            "account_id": obj.get("account_id"),
            "status": obj.get("status")
        })
        return _obj





# coding: utf-8

"""
    Secore API

    API for the Seres core platform

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from seres_client.api.users_api import UsersApi


class TestUsersApi(unittest.TestCase):
    """UsersApi unit test stubs"""

    def setUp(self) -> None:
        self.api = UsersApi()

    def tearDown(self) -> None:
        pass

    def test_create_user(self) -> None:
        """Test case for create_user

        Create User
        """
        pass

    def test_delete_user(self) -> None:
        """Test case for delete_user

        Delete User
        """
        pass

    def test_disable_user(self) -> None:
        """Test case for disable_user

        Disable User
        """
        pass

    def test_get_me(self) -> None:
        """Test case for get_me

        Get Me
        """
        pass

    def test_get_platform_user(self) -> None:
        """Test case for get_platform_user

        Get Platform User
        """
        pass

    def test_get_users(self) -> None:
        """Test case for get_users

        Get Users
        """
        pass

    def test_reactivate_user(self) -> None:
        """Test case for reactivate_user

        Reactivate User
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Secore API

    API for the Seres core platform

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from seres_client.models.flight_plan_schema import FlightPlanSchema

class TestFlightPlanSchema(unittest.TestCase):
    """FlightPlanSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> FlightPlanSchema:
        """Test FlightPlanSchema
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `FlightPlanSchema`
        """
        model = FlightPlanSchema()
        if include_optional:
            return FlightPlanSchema(
                reference = '',
                flight_plan_schema_id = 56,
                parent_flight_plan_id = 56,
                account_id = 56,
                is_private = True,
                type = 'refuel',
                id = 56,
                future_id = 56,
                created_by_id = 56,
                created = '',
                cancelled = True,
                origin_port_id = 56,
                destination_port_id = 56,
                offgrid_origin = True,
                offgrid_destination = True,
                legs = [
                    seres_client.models.flight_plan_leg_schema.FlightPlanLegSchema(
                        resource_assembly_schema_id = 56, 
                        critical = True, 
                        starting_datetime = '', 
                        is_launch_leg = True, 
                        is_landing_leg = True, 
                        origin_waypoint_id = 56, 
                        flight_plan_id = 56, 
                        generated = True, 
                        id = 56, 
                        future_id = 56, 
                        created = '', 
                        cancelled = True, 
                        created_by_id = 56, 
                        leg_resources = [
                            seres_client.models.flight_plan_leg_resource_schema.FlightPlanLegResourceSchema(
                                resource_id = 56, 
                                resource_assembly_schema_component_id = 56, 
                                configuration = 'primary', 
                                resource_schema_action_ids = [
                                    56
                                    ], 
                                leg_id = 56, 
                                id = 56, 
                                future_id = 56, 
                                created = '', 
                                cancelled = True, 
                                created_by_id = 56, )
                            ], )
                    ],
                waypoints = [
                    seres_client.models.flight_plan_waypoint_schema.FlightPlanWaypointSchema(
                        port_id = 56, 
                        coordinate = seres_client.models.waypoint_coordinate_schema.WaypointCoordinateSchema(
                            longitude = '', 
                            latitude = '', 
                            altitude = '', ), 
                        flight_plan_id = 56, 
                        generated = True, 
                        id = 56, 
                        future_id = 56, 
                        created = '', 
                        cancelled = True, 
                        created_by_id = 56, )
                    ]
            )
        else:
            return FlightPlanSchema(
                reference = '',
                account_id = 56,
                id = 56,
                future_id = 56,
                created_by_id = 56,
                created = '',
                cancelled = True,
                legs = [
                    seres_client.models.flight_plan_leg_schema.FlightPlanLegSchema(
                        resource_assembly_schema_id = 56, 
                        critical = True, 
                        starting_datetime = '', 
                        is_launch_leg = True, 
                        is_landing_leg = True, 
                        origin_waypoint_id = 56, 
                        flight_plan_id = 56, 
                        generated = True, 
                        id = 56, 
                        future_id = 56, 
                        created = '', 
                        cancelled = True, 
                        created_by_id = 56, 
                        leg_resources = [
                            seres_client.models.flight_plan_leg_resource_schema.FlightPlanLegResourceSchema(
                                resource_id = 56, 
                                resource_assembly_schema_component_id = 56, 
                                configuration = 'primary', 
                                resource_schema_action_ids = [
                                    56
                                    ], 
                                leg_id = 56, 
                                id = 56, 
                                future_id = 56, 
                                created = '', 
                                cancelled = True, 
                                created_by_id = 56, )
                            ], )
                    ],
                waypoints = [
                    seres_client.models.flight_plan_waypoint_schema.FlightPlanWaypointSchema(
                        port_id = 56, 
                        coordinate = seres_client.models.waypoint_coordinate_schema.WaypointCoordinateSchema(
                            longitude = '', 
                            latitude = '', 
                            altitude = '', ), 
                        flight_plan_id = 56, 
                        generated = True, 
                        id = 56, 
                        future_id = 56, 
                        created = '', 
                        cancelled = True, 
                        created_by_id = 56, )
                    ],
        )
        """

    def testFlightPlanSchema(self):
        """Test FlightPlanSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Secore API

    API for the Seres core platform

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from seres_client.models.paginated_response_schema_flight_plan_creation_request_schema import PaginatedResponseSchemaFlightPlanCreationRequestSchema

class TestPaginatedResponseSchemaFlightPlanCreationRequestSchema(unittest.TestCase):
    """PaginatedResponseSchemaFlightPlanCreationRequestSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PaginatedResponseSchemaFlightPlanCreationRequestSchema:
        """Test PaginatedResponseSchemaFlightPlanCreationRequestSchema
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PaginatedResponseSchemaFlightPlanCreationRequestSchema`
        """
        model = PaginatedResponseSchemaFlightPlanCreationRequestSchema()
        if include_optional:
            return PaginatedResponseSchemaFlightPlanCreationRequestSchema(
                items = [
                    seres_client.models.flight_plan_creation_request_schema.FlightPlanCreationRequestSchema(
                        flight_plan_schema_id = 56, 
                        reference = '', 
                        future_id = 56, 
                        meta_launch_now = True, 
                        meta_critical_leg_datetime = null, 
                        meta_critical_leg_id = 56, 
                        meta_landing_datetime = null, 
                        meta_launch_datetime = null, 
                        parent_flight_plan_creation_request_id = 56, 
                        primary_bot_id = 56, 
                        primary_bot_schema_id = 56, 
                        primary_payload_id = 56, 
                        primary_payload_schema_id = 56, 
                        resource_assembly_schema_id = 56, 
                        created_by_id = 56, 
                        account_id = 56, 
                        id = 56, 
                        created = '', 
                        status = 'pending', 
                        flight_plan_id = 56, )
                    ],
                has_next = True,
                has_prev = True,
                next_num = 56,
                prev_num = 56,
                page = 56,
                pages = 56,
                total = 56,
                per_page = 56
            )
        else:
            return PaginatedResponseSchemaFlightPlanCreationRequestSchema(
                items = [
                    seres_client.models.flight_plan_creation_request_schema.FlightPlanCreationRequestSchema(
                        flight_plan_schema_id = 56, 
                        reference = '', 
                        future_id = 56, 
                        meta_launch_now = True, 
                        meta_critical_leg_datetime = null, 
                        meta_critical_leg_id = 56, 
                        meta_landing_datetime = null, 
                        meta_launch_datetime = null, 
                        parent_flight_plan_creation_request_id = 56, 
                        primary_bot_id = 56, 
                        primary_bot_schema_id = 56, 
                        primary_payload_id = 56, 
                        primary_payload_schema_id = 56, 
                        resource_assembly_schema_id = 56, 
                        created_by_id = 56, 
                        account_id = 56, 
                        id = 56, 
                        created = '', 
                        status = 'pending', 
                        flight_plan_id = 56, )
                    ],
                has_next = True,
                has_prev = True,
                page = 56,
                pages = 56,
                total = 56,
                per_page = 56,
        )
        """

    def testPaginatedResponseSchemaFlightPlanCreationRequestSchema(self):
        """Test PaginatedResponseSchemaFlightPlanCreationRequestSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
